@@ -1,4 +1,4 @@
-# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Queue/Stomp.pm 2909 2007-09-30T13:06:51.115468Z daisuke  $
+# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Queue/Stomp.pm 9749 2007-11-25T00:31:40.483416Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved
@@ -9,8 +9,9 @@ use warnings;
 use base qw(Swarmage::Queue);
 use MIME::Base64;
 use Net::Stomp;
-use Storable qw(freeze thaw);
+use Storable qw(nfreeze thaw);
 use Swarmage::Task;
+use constant DEBUG => 0;
 
 __PACKAGE__->mk_group_accessors(simple => qw(connect_info subscriptions stomp read_delay));
 
@@ -22,7 +23,8 @@ sub new
 
     $args{read_delay} ||= '0.05';
     my $connect_info = $args{connect_info} || Carp::croak("No connect_info provided");
-    $connect_info->{port}     ||= 61613;
+    $connect_info->{port}       ||= 61613;
+    $connect_info->{persistent} ||= 'true';
     if (! $connect_info || (! $connect_info->{hostname} || ! $connect_info->{port} || ! $connect_info->{login} || ! $connect_info->{passcode})) {
         Carp::croak("No connect_info provided");
     }
@@ -38,16 +40,20 @@ sub insert
 
     my $message = $opts{message} || Carp::croak("No message specified");
     my $queue   = $opts{queue}   ||
-        ref($message) && $message->isa('Swarmage::Message') ? $message->destination : 
-        Carp::croak("No queue specified")
+        ref($message) && $message->isa('Swarmage::Message') ? $message->destination : ''
     ;
+    if (! $queue) {
+        Carp::croak("No queue specified");
+    }
+
     if ($queue !~ m{^/queue/}) {
         $queue = "/queue/$queue";
     }
 
     $self->ensure_connected->send({
         destination => $queue,
-        body        => encode_base64( freeze( $message ) )
+        body        => encode_base64( nfreeze( $message ) ),
+        persistent  => $message->persistent ? 'true' : 'false',
     }) or Carp::croak("Could not send message: $!");
 }
 
@@ -60,16 +66,24 @@ sub fetch
         $queue = "/queue/$queue";
     }
     $self->ensure_subscribed( $queue );
-    if ($self->stomp->can_read({ timeout => $self->read_delay })) {
-        my $frame = $self->stomp->receive_frame;
+    my $stomp = $self->stomp;
+    if ($stomp->can_read({ timeout => $self->read_delay })) {
+        # can_read may return on eof as well, so make sure socket is connected
+        if (! $stomp->socket->connected || $stomp->socket->eof) {
+            print STDERR "Socket is not available\n";
+            return ();
+        }
+
+        my $frame = $stomp->receive_frame;
         if ($frame->command eq 'ERROR') {
             die "received stomp error: " . $frame->body;
         }
-        $self->stomp->ack({ frame => $frame });
+        $stomp->ack({ frame => $frame });
         my $ret   =  eval { thaw( decode_base64($frame->body) ) };
+        die if $@;
+
         if (! $ret->attr) { $ret->attr({}) }
         $ret->attr->{frame} = $frame;
-        die if $@;
         return $ret;
     }
     return;
@@ -78,16 +92,29 @@ sub fetch
 sub ensure_connected
 {
     my $self = shift;
+    my $connect = 0;
     my $stomp = $self->stomp;
-    if (! $stomp || ! $stomp->socket->connected || $stomp->socket->eof) {
-        $stomp->socket->close if $stomp;
+    if (! $stomp ) {
+        print STDERR "$$ Creating new Net::Stomp instance\n" if DEBUG;
+        $connect = 1;
+    } elsif ( ! $stomp->socket ) {
+        print STDERR "$$ No socket available for Net::Stomp, (re)connecting\n" if DEBUG;
+        $connect = 1;
+    } elsif ( ! $stomp->socket->connected || $stomp->socket->eof) {
+        print STDERR "$$ Socket for Net::Stomp not connected, (re)connecting\n" if DEBUG;
+        $connect = 1;
+    }
+
+    if ($connect) {
+        $stomp->socket->close if $stomp && $stomp->socket;
         my $connect_info = $self->connect_info;
         $stomp = Net::Stomp->new({
-            hostname => $connect_info->{hostname},
-            port => $connect_info->{port},
+            hostname   => $connect_info->{hostname},
+            port       => $connect_info->{port},
+            persistent => $connect_info->{persistent},
         });
         $stomp->connect({
-            login => $connect_info->{login},
+            login    => $connect_info->{login},
             passcode => $connect_info->{passcode},
         });
         $self->stomp($stomp);
