@@ -1,4 +1,4 @@
-# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Task.pm 2425 2007-09-03T10:56:40.325353Z daisuke  $
+# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Task.pm 9170 2007-11-14T14:35:16.376408Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -9,20 +9,21 @@ use warnings;
 use Swarmage::Message;
 our @ISA = qw(Swarmage::Message);
 
-__PACKAGE__->mk_group_accessors(simple => qw(task_class source attr));
+__PACKAGE__->mk_group_accessors(simple => qw(task_class));
 
 sub new
 {
     my $class = shift;
     my %args = @_;
-    my $self = $class->next::method(attr => {}, @_, type => 'task');
+    my $self = $class->next::method(
+        @_,
+        type => 'task'
+    );
 
-    foreach my $arg qw(task_class) {
-        $self->$arg( $args{ $arg } );
-    }
-    if (! $self->destination) {
+    if (! $self->destination && $self->task_class) {
         $self->destination("task/" . $self->task_class);
     }
+    
     return $self;
 }
 
@@ -38,4 +39,20 @@ Swarmage::Task
 
 =head2 new
 
+=head2 type
+
+=head2 data
+
+=head2 destination
+
+=head2 postback
+
+=head2 persistent
+
+=head2 task_class
+
+=head2 source
+
+=head2 attr
+
 =cut
